# color-printtext
![image](https://user-images.githubusercontent.com/78240988/160273481-3bdbedb7-5580-4975-833a-a611bcbc7a8a.png)<br>
<a href="https://pypi.org/project/color-printtext/"><img src="https://img.shields.io/pypi/v/color-printtext.svg" alt="pypi Vertion" /></a>
<a href="https://pypi.org/project/color-printtext/"><img src="https://img.shields.io/pypi/pyversions/color-printtext.svg" alt="Python Vertion" /></a>
<a href="https://pepy.tech/project/color-printtext"><img src="https://static.pepy.tech/badge/color-printtext" alt="Total downloads" /></a>  
[pypi](https://pypi.org/project/color-printtext/)<br>
[wiki](https://github.com/gx1285/color-printtext/blob/main/docs/index.md)<br>
A module that specifies the color of print.  
# How to use
It can be installed using pip.
```sh
python3 -m pip install -U color-printtext
```
On Windows, install with this command.
```sh
py -3 -m pip install -U color-printtext
```
If you have passed PATH, you can install it with this command.
```sh
pip install -U color-printtext
```
Install with
Sample code
```py
import colorprinttext
colorprinttext.cprint('test','red')
```
